update_engine: Use GetDlcsToUpdate() instead of GetInstalled()

The meaning of GetInstalled() DBus in dlcservice have changed. So we need
to get the list of DLCs that ought to be updated from the new DBus
GetDlcsToUpdate().

Also rename all dlc_module_ids to dlc_ids.

BUG=chromium:1071654
TEST=cros_workon_make --board reef --test update_engine

Cq-Depend: chromium:2157669
Change-Id: I02e450a1fd75f8b387eb8a107c9c8a32f3e01e6e
Reviewed-on: https://chromium-review.googlesource.com/c/aosp/platform/system/update_engine/+/2163441
Tested-by: Amin Hassani <ahassani@chromium.org>
Reviewed-by: Andrew Lassalle <andrewlassalle@chromium.org>
Reviewed-by: Jae Hoon Kim <kimjae@chromium.org>
Commit-Queue: Amin Hassani <ahassani@chromium.org>
diff --git a/common/dlcservice_interface.h b/common/dlcservice_interface.h
index 3524d50..70b74ab 100644
--- a/common/dlcservice_interface.h
+++ b/common/dlcservice_interface.h
@@ -30,17 +30,17 @@
  public:
   virtual ~DlcServiceInterface() = default;
 
   // Returns true and a list of installed DLC module ids in |dlc_module_ids|.
   // On failure it returns false.
-  virtual bool GetInstalled(std::vector<std::string>* dlc_module_ids) = 0;
+  virtual bool GetDlcsToUpdate(std::vector<std::string>* dlc_ids) = 0;
 
   // Returns true if dlcservice successfully handled the install completion
   // method call, otherwise false.
-  virtual bool InstallCompleted(const std::vector<std::string>& ids) = 0;
+  virtual bool InstallCompleted(const std::vector<std::string>& dlc_ids) = 0;
 
   // Returns true if dlcservice successfully handled the update completion
   // method call, otherwise false.
-  virtual bool UpdateCompleted(const std::vector<std::string>& ids) = 0;
+  virtual bool UpdateCompleted(const std::vector<std::string>& dlc_ids) = 0;
 
  protected:
   DlcServiceInterface() = default;
@@ -30,17 +30,17 @@
   virtual ~DlcServiceInterface() = default;
 
-  // Returns true and a list of installed DLC module ids in |dlc_module_ids|.
+  // Returns true and a list of installed DLC ids in |dlc_ids|.
   // On failure it returns false.